//Source file: CallRelatedSendInfo.java
//Date: June 2005
//User Interaction Interfaces for 3GPP TS 29.198-05 V6.4.0

package org.csapi.jr.se.ui;

/**
 * A call related 'Send Info' activity object.
 *
 */
public interface CallRelatedSendInfo extends org.csapi.jr.se.Activity {

	/**
	 * Returns a reference to the UICall responsible for creation of the
	 * CallRelatedSendInfo.
	 *
	 * @return    The UICall responsible for creation of the CallRelatedSendInfo
	 */
	org.csapi.jr.se.ui.UICall getUICall();


	/**
	 * Adds a CallRelatedSendInfoListener which is interested in events generated
	 * by the CallRelatedSendInfo.
	 *
	 * @param  callRelatedSendInfoListener  Reference to the CallRelatedSendInfoListener 
	 *	which is to be added as a listener.
	 */
	void addCallRelatedSendInfoListener(org.csapi.jr.se.ui.CallRelatedSendInfoListener callRelatedSendInfoListener);


	/**
	 * Removes a CallRelatedSendInfoListener which is no longer interested events
	 * generated by the CallRelatedSendInfo.
	 *
	 * @param  callRelatedSendInfoListener  Reference to the CallRelatedSendInfoListener 
	 *	which is to be removed as a listener.
	 */
	void removeCallRelatedSendInfoListener(org.csapi.jr.se.ui.CallRelatedSendInfoListener callRelatedSendInfoListener);


	/**
	 * This asynchronous method plays an announcement or sends other information
	 * to the user.
	 *
	 * @param  info  Specifies the information to send to the user.<br>
	 *      This information can be: <br>
         *      - an infoID, identifying pre-defined information to be send
	 *      (announcement and/or text);
	 *      - a string, defining the text to be sent;
	 *      - a URL, identifying pre-defined information or data to be sent 
	 *      to or downloaded into the terminal.
	 * @param  language   Specifies the language of the information to be send to the user
	 * @param  variableInfo  Defines the variable part of the information to send to the user
	 * @param  repeatIndicator  Defines how many times the information shall be sent to 
	 *	the end-user.<br>
	 *      A value of zero (0) indicates that the announcement shall be repeated
	 *      until the call or call leg is released or an abortActionReq() is sent
	 * @param  responseRequested  Specifies if a response is required from the call user 
	 *	interaction service, and any action the service should take
	 * @exception  org.csapi.jr.se.PlatformException  if the implementation
	 *      detected an internal (for example, communication) error
	 * @exception  java.lang.IllegalStateException  if the JR API
	 *      object is not in a state suitable for the invocation
	 * @exception  org.csapi.jr.se.CommonException  defines the structure 
	 *      of the exception class which is applicable to all methods
	 * @exception  org.csapi.jr.se.InvalidNetworkStateException   if the sequence of
	 *      method calls is allowed by the gateway but the underlying protocol can
	 *      not support it
	 * @exception  org.csapi.jr.se.ui.IllegalIdException  if an information id
	 *      specified is invalid
	 */
	void sendInfoReq(
			org.csapi.jr.se.ui.UIInfo info,
			java.lang.String language,
			org.csapi.jr.se.ui.UIVariableInfo[] variableInfo,
			int repeatIndicator,
			int responseRequested)
			 throws org.csapi.jr.se.PlatformException,
			java.lang.IllegalStateException,
			org.csapi.jr.se.CommonException,
			org.csapi.jr.se.InvalidNetworkStateException,
			org.csapi.jr.se.ui.IllegalIdException;


	/**
	 * This asynchronous method aborts a user interaction operation, for example,
	 * a sendInfoReq(), from the specified call leg. The call and call leg are
	 * otherwise unaffected. The user interaction call service interrupts the
	 * current action on the specified leg.
	 *
	 * @exception  org.csapi.jr.se.PlatformException  if the implementation
	 *      detected an internal (for example, communication) error
	 * @exception  java.lang.IllegalStateException  if the JR API
	 *      object is not in a state suitable for the invocation
	 * @exception  org.csapi.jr.se.CommonException  defines the structure 
	 *      of the exception class which is applicable to all methods
	 */
	void abortActionReq()
			 throws org.csapi.jr.se.PlatformException,
			java.lang.IllegalStateException,
			org.csapi.jr.se.CommonException;
}
