//Source file: UIEventInfo.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V6.4.0

package org.csapi.jr.se.ui;

/**
 * Defines the Sequence of Data Elements that specify a UI notification.
 * 
 */
public final class UIEventInfo implements java.io.Serializable {

    private org.csapi.jr.se.Address originatingAddress;
    private org.csapi.jr.se.Address destinationAddress;
    private String serviceCode;
    private org.csapi.jr.se.ui.UIEventInfoDataType dataTypeIndication;
    private String dataString;

    /**
     * Creates a new UIEventInfo instance.
     */
    public UIEventInfo () {}

    /**
     * Creates a new UIEventInfo instance.
     * @param _originatingAddress   Defines the originating address. 
     * @param _destinationAddress   Defines the destination address.
     * @param _serviceCode   Defines a 2-digit code indicating the UI to be triggered. The value is operator specific.
     * @param _dataTypeIndication   Identifies the type of contents in UIEventData
     * @param _dataString   Freely defined data string with a limited length for example 160 bytes according to the network policy.
     */
    public UIEventInfo (org.csapi.jr.se.Address _originatingAddress, org.csapi.jr.se.Address _destinationAddress, String _serviceCode, org.csapi.jr.se.ui.UIEventInfoDataType _dataTypeIndication, String _dataString) {

        this.originatingAddress = _originatingAddress;
        this.destinationAddress = _destinationAddress;
        this.serviceCode = _serviceCode;
        this.dataTypeIndication = _dataTypeIndication;
        this.dataString = _dataString;
    }

    /**
     * This method returns a originatingAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getOriginatingAddress() {
        return originatingAddress;
    }

    /**
     * This method returns a destinationAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getDestinationAddress() {
        return destinationAddress;
    }

    /**
     * This method returns a serviceCode.
     * 
     * @return a String value
     */
    public String getServiceCode() {
        return serviceCode;
    }

    /**
     * This method returns a dataTypeIndication.
     * 
     * @return a org.csapi.jr.se.ui.UIEventInfoDataType value
     */
    public org.csapi.jr.se.ui.UIEventInfoDataType getDataTypeIndication() {
        return dataTypeIndication;
    }

    /**
     * This method returns a dataString.
     * 
     * @return a String value
     */
    public String getDataString() {
        return dataString;
    }


    /**
     * This method sets a originatingAddress.
     */ 
    public void setOriginatingAddress(org.csapi.jr.se.Address originatingAddress) {
        this.originatingAddress = originatingAddress;
    }

    /**
     * This method sets a destinationAddress.
     */ 
    public void setDestinationAddress(org.csapi.jr.se.Address destinationAddress) {
        this.destinationAddress = destinationAddress;
    }

    /**
     * This method sets a serviceCode.
     */ 
    public void setServiceCode(String serviceCode) {
        this.serviceCode = serviceCode;
    }

    /**
     * This method sets a dataTypeIndication.
     */ 
    public void setDataTypeIndication(org.csapi.jr.se.ui.UIEventInfoDataType dataTypeIndication) {
        this.dataTypeIndication = dataTypeIndication;
    }

    /**
     * This method sets a dataString.
     */ 
    public void setDataString(String dataString) {
        this.dataString = dataString;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIEventInfo)) {
            return false;
        } 
        UIEventInfo uIEventInfo = (UIEventInfo) o;
        if ((this.originatingAddress != null) && (uIEventInfo.originatingAddress != null)) {
            if(!(this.originatingAddress.equals(uIEventInfo.originatingAddress))) {
                return false;
            }
        }
        if ((this.destinationAddress != null) && (uIEventInfo.destinationAddress != null)) {
            if(!(this.destinationAddress.equals(uIEventInfo.destinationAddress))) {
                return false;
            }
        }
        if ((this.serviceCode != null) && (uIEventInfo.serviceCode != null)) {
            if(!(this.serviceCode.equals(uIEventInfo.serviceCode)))  {
                return false;
            }
        }
        if ((this.dataTypeIndication != null) && (uIEventInfo.dataTypeIndication != null)) {
            if(!(this.dataTypeIndication.equals(uIEventInfo.dataTypeIndication))) {
                return false;
            }
        }
        if ((this.dataString != null) && (uIEventInfo.dataString != null)) {
            if(!(this.dataString.equals(uIEventInfo.dataString)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIEventInfo

