//Source file: UIPronounceType.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V6.4.0

package org.csapi.jr.se.ui;

/**
 * Defines the pronunciation type.
The International Phonetic Alphabet (IPA) representation can be used to specify pronunciations.  For more information see:
	http://www2.arts.gla.ac.uk/IPA/ipachart.html
	http://charts.unicode.org/Unicode.charts/normal/U0250.html
Also, simple sound-alike replacements can be used, such as "I triple E" for IEEE. 
 *
 */
public final class UIPronounceType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static UIPronounceType[] _array = new UIPronounceType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UIPronounceType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The IPA pronunciation type
     */
    public static final int _UI_PRONOUNCE_IPA =  0;

    /**
     * The IPA pronunciation type
     */
    public static final UIPronounceType UI_PRONOUNCE_IPA = new UIPronounceType(_UI_PRONOUNCE_IPA);

    /**
     * The simple sounds like replacement type
     */
    public static final int _UI_PRONOUNCE_SOUNDSLIKE =  1;

    /**
     * The simple sounds like replacement type
     */
    public static final UIPronounceType UI_PRONOUNCE_SOUNDSLIKE = new UIPronounceType(_UI_PRONOUNCE_SOUNDSLIKE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UIPronounceType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UIPronounceType object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_PRONOUNCE_IPA:
                return "UI_PRONOUNCE_IPA";
            case _UI_PRONOUNCE_SOUNDSLIKE:
                return "UI_PRONOUNCE_SOUNDSLIKE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UIPronounceType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIPronounceType)) {
            return false;
        }
        UIPronounceType uIPronounceType = (UIPronounceType) o; 
        if(!(this.getValue() == uIPronounceType.getValue())) {
            return false;
        }
        if (this.hashCode() != uIPronounceType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIPronounceType

