//Source file: UIRecognitionProperty.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V6.4.0

package org.csapi.jr.se.ui;

/**
 * Defines the Sequence of Data Elements that specify the additional properties for the recognition engine.  The TpUIRecognitionProperty is a hint to the recognition engine on how it should interpret the input.
The defined properties are:
P_RECOGNITION_PROPERTY_CONFIDENCE_LEVEL - The speech recognition confidence level, a float value in the range of 0.0 to 1.0. Results are rejected when the recognitions engine's confidence in its interpretation is below this threshold. A value of 0.0 means minimum confidence is needed for a recognition, and a value of 1.0 requires maximum confidence. The default value is 0.5. 
P_RECOGNITION_PROPERTY_SENSITIVITY - Set the sensitivity level. A value of 1.0 means that it is highly sensitive to quiet input. A value of 0.0 means it is least sensitive to noise. The default value is 0.5.
P_RECOGNITION_PROPERTY_SPEEDVSACCURACY - A hint specifying the desired balance between speed vs. accuracy. A value of 0.0 means fastest recognition. A value of 1.0 means best accuracy. The default is value 0.5.
P_RECOGNITION_PROPERTY_COMPLETE_TIMEOUT - The speech timeout value to use when an active grammar is matched.
 * 
 */
public final class UIRecognitionProperty implements java.io.Serializable {

    private String propertyName;
    private String propertyValue;

    /**
     * Creates a new UIRecognitionProperty instance.
     */
    public UIRecognitionProperty () {}

    /**
     * Creates a new UIRecognitionProperty instance.
     * @param _propertyName   Defines the name of the property.
     * @param _propertyValue   Defines the value of the property.
     */
    public UIRecognitionProperty (String _propertyName, String _propertyValue) {

        this.propertyName = _propertyName;
        this.propertyValue = _propertyValue;
    }

    /**
     * This method returns a propertyName.
     * 
     * @return a String value
     */
    public String getPropertyName() {
        return propertyName;
    }

    /**
     * This method returns a propertyValue.
     * 
     * @return a String value
     */
    public String getPropertyValue() {
        return propertyValue;
    }


    /**
     * This method sets a propertyName.
     */ 
    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    /**
     * This method sets a propertyValue.
     */ 
    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UIRecognitionProperty)) {
            return false;
        } 
        UIRecognitionProperty uIRecognitionProperty = (UIRecognitionProperty) o;
        if ((this.propertyName != null) && (uIRecognitionProperty.propertyName != null)) {
            if(!(this.propertyName.equals(uIRecognitionProperty.propertyName)))  {
                return false;
            }
        }
        if ((this.propertyValue != null) && (uIRecognitionProperty.propertyValue != null)) {
            if(!(this.propertyValue.equals(uIRecognitionProperty.propertyValue)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UIRecognitionProperty

