//Source file: UISynthesisInfoData.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V6.4.0

package org.csapi.jr.se.ui;

/**
 * Defines the Sequence of Data Elements that specify the information to use in generating the desired effects on the generated voice.  The speech synthesis parameters or processing tags will be interpreted as hints and may be ignored by the speech synthesis engine.  Note that the language is specified on the sendInfoReq() and sendInfoAndCollectReq() method calls.
The TextData field may contain the following tags to affect the processing of the text.  The <break> tag specifies a timing pause.  The <emp> tag specifies an emphasis on a word or phrase.
			<break size="milliseconds">	     // specifies a timing pause in the 
                                             // middle of the text in milliseconds
			<emp>A word</emp>				// apply emphasis to a word or words
 * 
 */
public final class UISynthesisInfoData implements java.io.Serializable {

    private org.csapi.jr.se.ui.UISynthesisGender speakerGender;
    private org.csapi.jr.se.ui.UISynthesisAge speakerAge;
    private org.csapi.jr.se.ui.UISynthesisRate speakerRate;
    private org.csapi.jr.se.ui.UISynthesisRange speakerRange;
    private String textData;
    private org.csapi.jr.se.ui.UIWordOverride[] wordOverrideSet;

    /**
     * Creates a new UISynthesisInfoData instance.
     */
    public UISynthesisInfoData () {}

    /**
     * Creates a new UISynthesisInfoData instance.
     * @param _speakerGender   Defines the gender of the speaker.
     * @param _speakerAge   Defines the age of the speaker.
     * @param _speakerRate   Defines the rate of the speaker.
     * @param _speakerRange   Defines the range of the speaker.
     * @param _textData   Defines the text to synthesize into speech.
     * @param _wordOverrideSet   Defines the pronunciation overrides.
     */
    public UISynthesisInfoData (org.csapi.jr.se.ui.UISynthesisGender _speakerGender, org.csapi.jr.se.ui.UISynthesisAge _speakerAge, org.csapi.jr.se.ui.UISynthesisRate _speakerRate, org.csapi.jr.se.ui.UISynthesisRange _speakerRange, String _textData, org.csapi.jr.se.ui.UIWordOverride[] _wordOverrideSet) {

        this.speakerGender = _speakerGender;
        this.speakerAge = _speakerAge;
        this.speakerRate = _speakerRate;
        this.speakerRange = _speakerRange;
        this.textData = _textData;
        this.wordOverrideSet = _wordOverrideSet;
    }

    /**
     * This method returns a speakerGender.
     * 
     * @return a org.csapi.jr.se.ui.UISynthesisGender value
     */
    public org.csapi.jr.se.ui.UISynthesisGender getSpeakerGender() {
        return speakerGender;
    }

    /**
     * This method returns a speakerAge.
     * 
     * @return a org.csapi.jr.se.ui.UISynthesisAge value
     */
    public org.csapi.jr.se.ui.UISynthesisAge getSpeakerAge() {
        return speakerAge;
    }

    /**
     * This method returns a speakerRate.
     * 
     * @return a org.csapi.jr.se.ui.UISynthesisRate value
     */
    public org.csapi.jr.se.ui.UISynthesisRate getSpeakerRate() {
        return speakerRate;
    }

    /**
     * This method returns a speakerRange.
     * 
     * @return a org.csapi.jr.se.ui.UISynthesisRange value
     */
    public org.csapi.jr.se.ui.UISynthesisRange getSpeakerRange() {
        return speakerRange;
    }

    /**
     * This method returns a textData.
     * 
     * @return a String value
     */
    public String getTextData() {
        return textData;
    }

    /**
     * This method returns a wordOverrideSet.
     * 
     * @return a org.csapi.jr.se.ui.UIWordOverride[] value
     */
    public org.csapi.jr.se.ui.UIWordOverride[] getWordOverrideSet() {
        return wordOverrideSet;
    }


    /**
     * This method sets a speakerGender.
     */ 
    public void setSpeakerGender(org.csapi.jr.se.ui.UISynthesisGender speakerGender) {
        this.speakerGender = speakerGender;
    }

    /**
     * This method sets a speakerAge.
     */ 
    public void setSpeakerAge(org.csapi.jr.se.ui.UISynthesisAge speakerAge) {
        this.speakerAge = speakerAge;
    }

    /**
     * This method sets a speakerRate.
     */ 
    public void setSpeakerRate(org.csapi.jr.se.ui.UISynthesisRate speakerRate) {
        this.speakerRate = speakerRate;
    }

    /**
     * This method sets a speakerRange.
     */ 
    public void setSpeakerRange(org.csapi.jr.se.ui.UISynthesisRange speakerRange) {
        this.speakerRange = speakerRange;
    }

    /**
     * This method sets a textData.
     */ 
    public void setTextData(String textData) {
        this.textData = textData;
    }

    /**
     * This method sets a wordOverrideSet.
     */ 
    public void setWordOverrideSet(org.csapi.jr.se.ui.UIWordOverride[] wordOverrideSet) {
        this.wordOverrideSet = wordOverrideSet;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UISynthesisInfoData)) {
            return false;
        } 
        UISynthesisInfoData uISynthesisInfoData = (UISynthesisInfoData) o;
        if ((this.speakerGender != null) && (uISynthesisInfoData.speakerGender != null)) {
            if(!(this.speakerGender.equals(uISynthesisInfoData.speakerGender))) {
                return false;
            }
        }
        if ((this.speakerAge != null) && (uISynthesisInfoData.speakerAge != null)) {
            if(!(this.speakerAge.equals(uISynthesisInfoData.speakerAge))) {
                return false;
            }
        }
        if ((this.speakerRate != null) && (uISynthesisInfoData.speakerRate != null)) {
            if(!(this.speakerRate.equals(uISynthesisInfoData.speakerRate))) {
                return false;
            }
        }
        if ((this.speakerRange != null) && (uISynthesisInfoData.speakerRange != null)) {
            if(!(this.speakerRange.equals(uISynthesisInfoData.speakerRange))) {
                return false;
            }
        }
        if ((this.textData != null) && (uISynthesisInfoData.textData != null)) {
            if(!(this.textData.equals(uISynthesisInfoData.textData)))  {
                return false;
            }
        }
        if(!(this.wordOverrideSet == uISynthesisInfoData.wordOverrideSet))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UISynthesisInfoData

