//Source file: UISynthesisRange.java
//Date: June 2005
//User Interaction Data Types for 3GPP TS 29.198-05 V6.4.0

package org.csapi.jr.se.ui;

/**
 * Defines the range or liveliness of the speech.
 *
 */
public final class UISynthesisRange implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static UISynthesisRange[] _array = new UISynthesisRange[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private UISynthesisRange(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Very Calm or monotone speech
     */
    public static final int _UI_RANGE_CALMER =  0;

    /**
     * Very Calm or monotone speech
     */
    public static final UISynthesisRange UI_RANGE_CALMER = new UISynthesisRange(_UI_RANGE_CALMER);

    /**
     * Moderately calm speech
     */
    public static final int _UI_RANGE_CALM =  1;

    /**
     * Moderately calm speech
     */
    public static final UISynthesisRange UI_RANGE_CALM = new UISynthesisRange(_UI_RANGE_CALM);

    /**
     * Average speech
     */
    public static final int _UI_RANGE_AVERAGE =  2;

    /**
     * Average speech
     */
    public static final UISynthesisRange UI_RANGE_AVERAGE = new UISynthesisRange(_UI_RANGE_AVERAGE);

    /**
     * Moderately excited or lively speech
     */
    public static final int _UI_RANGE_EXCITED =  3;

    /**
     * Moderately excited or lively speech
     */
    public static final UISynthesisRange UI_RANGE_EXCITED = new UISynthesisRange(_UI_RANGE_EXCITED);

    /**
     * Excited or lively speech
     */
    public static final int _UI_RANGE_MORE_EXCITED =  4;

    /**
     * Excited or lively speech
     */
    public static final UISynthesisRange UI_RANGE_MORE_EXCITED = new UISynthesisRange(_UI_RANGE_MORE_EXCITED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved UISynthesisRange object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the UISynthesisRange object
     */
    public String getValueText() {
        switch (_value) {
            case _UI_RANGE_CALMER:
                return "UI_RANGE_CALMER";
            case _UI_RANGE_CALM:
                return "UI_RANGE_CALM";
            case _UI_RANGE_AVERAGE:
                return "UI_RANGE_AVERAGE";
            case _UI_RANGE_EXCITED:
                return "UI_RANGE_EXCITED";
            case _UI_RANGE_MORE_EXCITED:
                return "UI_RANGE_MORE_EXCITED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static UISynthesisRange getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof UISynthesisRange)) {
            return false;
        }
        UISynthesisRange uISynthesisRange = (UISynthesisRange) o; 
        if(!(this.getValue() == uISynthesisRange.getValue())) {
            return false;
        }
        if (this.hashCode() != uISynthesisRange.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // UISynthesisRange

